function LaunchQueueJob(md,options)
%LAUNCHQUEUEJOB- Launch job on cluster
%
%   Usage:
%      LaunchQueueJob(model,options)

%first, check we have the binary file and the queueing script
if ~exist([ md.name '.bin'],'file'),
	error('LaunchQueueJobcosmos error message: Binary input file missing, cannot go forward');
end

if ~exist([ md.name '.queue'],'file'),
	error('LaunchQueueJobcosmos error message: queueing script missing, cannot go forward');
end

if md.qmu_analysis & ~exist([ md.name '.qmu.in'],'file'),
	error('LaunchQueueJobcosmos error message: missing dakota input file, cannot go forward');
end

if ~strcmpi(options.batch,'yes'),
	
	%compress the files into one zip.
	compressstring=['tar -zcf ' md.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
	if md.qmu_analysis,
		compressstring=[compressstring md.name '.qmu.in'];
	end
	system(compressstring);
	
	disp('uploading input file and queueing script');
	issmscpout(md.cluster.name,md.cluster.executionpath,md.cluster.login,md.cluster.port,{[md.runtimename '.tar.gz']});

	if strcmpi(options.upload,'off'),
		disp('launching solution sequence on remote cluster');
		issmssh(md.cluster.name,md.cluster.login,md.cluster.port,LaunchCommand(md.cluster,md.runtimename,md.name));
	end

else
	disp('batch mode requested: not launching job interactively');
	disp('launch solution sequence on remote cluster by hand');
end
